@@ -1,9 +1,10 @@
 package Code::TidyAll::Plugin::JSBeautify;
 BEGIN {
-  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.10';
+  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.11';
 }
 use IPC::System::Simple qw(run);
 use Moo;
+use Try::Tiny;
 extends 'Code::TidyAll::Plugin';
 
 sub _build_cmd { 'js-beautify' }
@@ -11,7 +12,12 @@ sub _build_cmd { 'js-beautify' }
 sub transform_file {
     my ( $self, $file ) = @_;
 
-    run( sprintf( "%s --replace %s %s", $self->cmd, $self->argv, $file ) );
+    try {
+        run( sprintf( "%s --replace %s %s", $self->cmd, $self->argv, $file ) );
+    }
+    catch {
+        die sprintf( "%s exited with error - possibly bad arg list '%s'", $self->cmd, $self->argv );
+    };
 }
 
 1;
@@ -26,7 +32,7 @@ Code::TidyAll::Plugin::JSBeautify - use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
