@@ -1,18 +1,18 @@
 package Code::TidyAll::Plugin::PerlCritic;
 BEGIN {
-  $Code::TidyAll::Plugin::PerlCritic::VERSION = '0.10';
+  $Code::TidyAll::Plugin::PerlCritic::VERSION = '0.11';
 }
-use Perl::Critic::Command qw();
 use Capture::Tiny qw(capture_merged);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
+sub _build_cmd { 'perlcritic' }
+
 sub validate_file {
     my ( $self, $file ) = @_;
 
-    my @argv = ( split( /\s/, $self->argv ), $file );
-    local @ARGV = @argv;
-    my $output = capture_merged { Perl::Critic::Command::run() };
+    my $cmd = sprintf( "%s %s %s", $self->cmd, $self->argv, $file );
+    my $output = capture_merged { system($cmd) };
     die "$output\n" if $output !~ /^.* source OK\n/;
 }
 
@@ -28,7 +28,7 @@ Code::TidyAll::Plugin::PerlCritic - use perlcritic with tidyall
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
