@@ -1,7 +1,8 @@
 package Code::TidyAll::Plugin::PerlTidy;
 BEGIN {
-  $Code::TidyAll::Plugin::PerlTidy::VERSION = '0.10';
+  $Code::TidyAll::Plugin::PerlTidy::VERSION = '0.11';
 }
+use Capture::Tiny qw(capture_merged);
 use Perl::Tidy;
 use Moo;
 extends 'Code::TidyAll::Plugin';
@@ -9,15 +10,22 @@ extends 'Code::TidyAll::Plugin';
 sub transform_source {
     my ( $self, $source ) = @_;
 
-    my $errorfile;
-    no strict 'refs';
-    Perl::Tidy::perltidy(
-        argv        => $self->argv,
-        source      => \$source,
-        destination => \my $destination,
-        errorfile   => \$errorfile
-    );
-    die $errorfile if $errorfile;
+    # perltidy reports errors in two different ways.
+    # Argument/profile errors are output and an error_flag is returned.
+    # Syntax errors are sent to errorfile.
+    #
+    my ( $output, $error_flag, $errorfile, $destination );
+    $output = capture_merged {
+        $error_flag = Perl::Tidy::perltidy(
+            argv        => $self->argv,
+            source      => \$source,
+            destination => \$destination,
+            errorfile   => \$errorfile
+        );
+    };
+    die $errorfile       if $errorfile;
+    die $output          if $error_flag;
+    print STDERR $output if defined($output);
     return $destination;
 }
 
@@ -33,7 +41,7 @@ Code::TidyAll::Plugin::PerlTidy - use perltidy with tidyall
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
