@@ -1,6 +1,6 @@
 package Code::TidyAll::t::Plugin::JSBeautify;
 BEGIN {
-  $Code::TidyAll::t::Plugin::JSBeautify::VERSION = '0.10';
+  $Code::TidyAll::t::Plugin::JSBeautify::VERSION = '0.11';
 }
 use Test::Class::Most parent => 'Code::TidyAll::t::Plugin';
 
@@ -14,8 +14,13 @@ sub test_main : Tests {
     );
     $self->tidyall(
         source      => $source,
-        conf        => { argv => '--indent-size 2 --brace-style expand' },
-        expect_tidy => 'sp.toggleResult = function(id)\n{\n  foo(id)\n}\n',
+        conf        => { argv => '--indent-size 3 --brace-style expand' },
+        expect_tidy => 'sp.toggleResult = function(id)\n{\n   foo(id)\n}\n',
+    );
+    $self->tidyall(
+        source       => $source,
+        conf         => { argv => '--badoption' },
+        expect_error => qr/exited with error/
     );
 }
 
