@@ -1,6 +1,6 @@
 package Code::TidyAll::t::Plugin::MasonTidy;
 BEGIN {
-  $Code::TidyAll::t::Plugin::MasonTidy::VERSION = '0.10';
+  $Code::TidyAll::t::Plugin::MasonTidy::VERSION = '0.11';
 }
 use Test::Class::Most parent => 'Code::TidyAll::t::Plugin';
 
@@ -12,18 +12,23 @@ sub test_main : Tests {
     $source = '%if($foo) {\n%bar(1,2);\n%}';
     $self->tidyall(
         source      => $source,
-        expect_tidy => '% if ($foo) {\n%   bar( 1, 2 );\n% }'
+        expect_tidy => '% if ($foo) {\n%     bar( 1, 2 );\n% }'
     );
     $self->tidyall(
         source      => $source,
-        conf        => { argv => '--perltidy-argv="-pt=2"' },
-        expect_tidy => '% if ($foo) {\n%   bar(1, 2);\n% }'
+        conf        => { argv => '--perltidy-argv="-pt=2 -i=3"' },
+        expect_tidy => '% if ($foo) {\n%    bar(1, 2);\n% }'
     );
     $self->tidyall(
         source      => $source,
         conf        => { argv => '--perltidy-line-argv=" "' },
         expect_tidy => '% if ($foo) {\n%     bar( 1, 2 );\n% }'
     );
+    $self->tidyall(
+        source       => $source,
+        conf         => { argv => '--badoption' },
+        expect_error => qr/Unknown option: badoption/
+    );
 }
 
 1;
